import React, { useEffect, useState } from "react";
import {
  useLazyDeleteFromCartQuery,
  useLazyUpdateCartQuery,
} from "../../app/features/cart/apiSlice";
import useLanguage from "../../hooks/useLanguage";

function CartItem({ product }) {
  const language = useLanguage();
  const [qty, setQty] = useState(product?.qty || 0);
  const [updateQty, { isError }] = useLazyUpdateCartQuery();
  const [deleteCartItem] = useLazyDeleteFromCartQuery();

  useEffect(() => {
    const timeoutId = setTimeout(() => {
      if (product.qty != qty && qty) {
        updateQty({ cartId: product.id, quantity: qty });
      }
    }, 1000);

    return () => clearTimeout(timeoutId);
  }, [qty]);

  useEffect(() => {
    if (isError) {
      setQty(product?.qty);
    }
  }, [isError]);
  return (
    <tr className="lg:p-5 py-5 grid lg:gap-9 gap-3 xl:grid-cols-12 grid-cols-7  justify-start items-center border-b border-primary-100">
      <td className="flex h-fit items-center gap-3 col-span-7 ">
        <img
          src={process.env.BASE_URL + product?.product?.thumb_image}
          alt="productImg"
          className=" rounded-lg border border-gray-50 w-[104px] max-w-28 lg:w-auto "
        />
        <h4 className=" lg:text-lg text-sm font-bold text-dark-300 notranslate">
          {product?.product?.name}
        </h4>
      </td>
      <td className=" xl:col-span-2 text-sm font-medium col-span-3">
        <p className=" text-dark-300 mb-1">
          {product?.warehouse_product?.price
            ? product.warehouse_product?.price
            : product?.product?.price}
          ${" "}
          <span className=" text-primary-200 notranslate">
            / {language["Ton"]}
          </span>
        </p>
        <div className=" bg-primary-100 rounded flex items-center px-2 py-1 bg-opacity-40 w-fit ">
          <input
            type="number"
            value={qty}
            max={Number(product?.warehouse_product.stock)}
            min={1}
            name={product?.id}
            onChange={(e) => setQty(e.target.value)}
            className="numberInput border-none outline-none focus:border-none focus:outline-none w-full bg-transparent text-base font-bold h-fit p-0 max-w-16"
          />
          <p className=" text-sm font-normal text-primary-200 notranslate">
            {language["Ton"]}
          </p>
        </div>
      </td>
      <td className=" xl:col-span-2 col-span-3">
        <p className=" lg:text-xl text-lg  font-bold text-dark-300">
          $
          {(
            Number(
              product?.warehouse_product?.price
                ? product.warehouse_product?.price
                : product?.product?.price
            ) * qty
          ).toFixed(2)}
        </p>
        {/* <p className=" text-sm font-normal text-primary-200">VAT rate: 20%</p> */}
      </td>
      <td
        className="col-span-1 cursor-pointer"
        onClick={() => deleteCartItem(product.id)}
      >
        <svg
          xmlns="http://www.w3.org/2000/svg"
          width="26"
          height="26"
          viewBox="0 0 26 26"
          fill="none"
        >
          <path
            d="M16.064 16.064L9.93571 9.93571M9.9357 16.064L16.064 9.93571M12.9998 23.8332C18.9829 23.8332 23.8332 18.9829 23.8332 12.9998C23.8332 7.01675 18.9829 2.1665 12.9998 2.1665C7.01675 2.1665 2.1665 7.01675 2.1665 12.9998C2.1665 18.9829 7.01675 23.8332 12.9998 23.8332Z"
            stroke="#EB5757"
            strokeWidth="1.5"
            strokeLinecap="round"
          />
        </svg>
      </td>
    </tr>
  );
}

export default CartItem;
